@@ -55,10 +55,15 @@ class Нечёткая_переменная: # Кортеж вида (Имя,A),
         return "{Имя} = {Функция}".format(Имя = self.Имя, Функция = self.A)
 
 class Лингвистическая_переменная: # Кортеж вида (бета,T,X,G,M), где 
-    def __init__(self, Имя:str, Значение:float = None, X:List[int] = None, T:List[Нечёткая_переменная] = None, G = None, M = None):
+    def __init__(self, Имя:str, Значение:float = None, 
+                 #X:List[int] = None, 
+                 T:List[Нечёткая_переменная] = None 
+                 #G = None, 
+                 #M = None
+                 ):
         self.Имя = Имя    # бета - имя переменной
         self.Значение = Значение  # Значение - точное скалярное значение лингвистической переменной (например для роста может быть от 150 до 200)
-        self.X = X if X is not None else []          # X - область определения терм-множества(универсум нечётких переменных), 
+        #self.X = X if X is not None else []          # X - область определения терм-множества(универсум нечётких переменных), 
         self.T = T if T is not None else []          # T - множество её значений(терм-множество состоящее из нечётких переменных) 
         #self.G = G          # G - синтаксическая процедура, позволяющая генерировать новые термы(значения)
         #self.M = M          # M - семантическая процедура, ставящая в соответствие каждому терму, полученному с помощью G нечёткое множество
